GEDCOM - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# GEDCOM

To build a site from your GEDCOM files, you must first convert them to Gramps XML:

1. Install and launch Gramps

2. Create a new family tree

3. Import your GEDCOM file under Family Trees > Import…

4. Export your family tree under Family Trees > Export…

5. As output format, choose one of the Gramps XML options

6. Use the Gramps to load the exported file